@@ -41,13 +41,14 @@ Example
 
     from nsfds2.init import CfgSetup, Fields
     from nsfds2.fdtd import FDTD
-    from fdgrid.mesh import Mesh
+    from fdgrid import mesh
 
     # Read simulation parameter in config file ~/nsfds2/nsfds2.conf
     cfg = CfgSetup()
 
     # Define the mesh
-    msh = Mesh((cfg.nx, cfg.nz), (cfg.dx, cfg.dz), origin=(cfg.ix0, cfg.iz0), obstacles=[])
+    msh = mesh.build('regular', (cfg.nx, cfg.nz), (cfg.dx, cfg.dz),
+                     origin=(cfg.ix0, cfg.iz0), obstacles=[])
 
     # Create simulation
     fdtd = FDTD(msh, cfg)
@@ -254,8 +255,8 @@ class FDTD:
     def update_pressure(self):
         """ Update pressure field """
 
-        self.fld.fdtools.p(self.fld.p, self.fld.r, self.fld.ru,
-                           self.fld.rv, self.fld.re)
+        self.fld.fdt.p(self.fld.p, self.fld.r, self.fld.ru,
+                       self.fld.rv, self.fld.re)
 
     @timing.proceed('vorticity')
     def update_vorticity(self):
@@ -277,9 +278,9 @@ class FDTD:
         """ Check if computation diverges. """
 
         if self.cfg.mesh == 'curvilinear':
-            self.res = self.fld.fdtools.residual(self.fld.p*self.msh.J)
+            self.res = self.fld.fdt.residual(self.fld.p*self.msh.J)
         else:
-            self.res = self.fld.fdtools.residual(self.fld.p)
+            self.res = self.fld.fdt.residual(self.fld.p)
 
 #        if (abs(self.res) > 100*self.pmax) or np.any(np.isnan(self.fld.p)):
         if np.any(np.isnan(self.fld.p)):
