@@ -74,17 +74,17 @@ class EulerianFluxes:
             if self.cfg.ftype == 'kh':
                 self.fld.Ke -= self.fld.update_flow(self.cfg.it)
 
-            self.fld.fdtools.adtime(self.fld.r, self.r, self.fld.K, irk)
-            self.fld.fdtools.adtime(self.fld.ru, self.ru, self.fld.Ku, irk)
-            self.fld.fdtools.adtime(self.fld.rv, self.rv, self.fld.Kv, irk)
-            self.fld.fdtools.adtime(self.fld.re, self.re, self.fld.Ke, irk)
+            self.fld.fdt.adtime(self.fld.r, self.r, self.fld.K, irk)
+            self.fld.fdt.adtime(self.fld.ru, self.ru, self.fld.Ku, irk)
+            self.fld.fdt.adtime(self.fld.rv, self.rv, self.fld.Kv, irk)
+            self.fld.fdt.adtime(self.fld.re, self.re, self.fld.Ke, irk)
 
             # Boundary conditions
             self.cout()
 
             # Compute p
-            self.fld.fdtools.p(self.fld.p, self.fld.r, self.fld.ru,
-                               self.fld.rv, self.fld.re)
+            self.fld.fdt.p(self.fld.p, self.fld.r, self.fld.ru,
+                           self.fld.rv, self.fld.re)
 
             if self.cfg.stype in ['harmonic', 'white', 'wav']:
                 self.fld.p += self.fld.update_source(self.cfg.it)
